@@ -38,6 +38,7 @@ extern "C" {
     ADM_PIXFRMT_BGR555,
     ADM_PIXFRMT_YV12 = ADM_PIXFRMT_IS_YUV,	// YUV420
     ADM_PIXFRMT_NV12,
+    ADM_PIXFRMT_YUVA420P,
     ADM_PIXFRMT_YUV422,
     ADM_PIXFRMT_UYVY422,
     ADM_PIXFRMT_YUV422P,
@@ -77,6 +78,7 @@ static AVPixelFormat ADMPixFrmt2LAVPixFmt(ADM_pixelFormat fromPixFrmt_)
     case ADM_PIXFRMT_YUV422: return AV_PIX_FMT_YUYV422;
     case ADM_PIXFRMT_UYVY422: return AV_PIX_FMT_UYVY422;
     case ADM_PIXFRMT_YV12: return AV_PIX_FMT_YUV420P;
+    case ADM_PIXFRMT_YUVA420P: return AV_PIX_FMT_YUVA420P;
     case ADM_PIXFRMT_NV12: return AV_PIX_FMT_NV12;
     case ADM_PIXFRMT_YUV422P: return AV_PIX_FMT_YUV422P;
     case ADM_PIXFRMT_RGB555: return AV_PIX_FMT_RGB555LE;
